@@ -17,13 +17,13 @@ class WBGenericDBManager(AbstractWBDBManager):
         if not added_or_modified_after:
             added_or_modified_after = '1970-01-01'
         with psycopg2.connect(self.connection_str) as conn, conn.cursor() as curs:
-            curs.execute("SELECT DISTINCT joinkey from pap_electronic_path WHERE pap_timestamp > %s "
+            curs.execute("SELECT DISTINCT joinkey, pap_timestamp from pap_electronic_path WHERE pap_timestamp > %s "
                          "ORDER BY pap_timestamp DESC",
                          (added_or_modified_after, ))
             res = curs.fetchall()
             exclude_ids = set(exclude_ids) if exclude_ids else set()
-            return [row[0] for row in res if row[0] not in exclude_ids and "WBPaper" + row[0] not in exclude_ids] \
-                if res else []
+            return list(set([row[0] for row in res if row[0] not in exclude_ids and "WBPaper" + row[0] not in
+                             exclude_ids])) if res else []
 
     def get_paper_ids_with_pap_types(self, pap_types: List[str]):
         with psycopg2.connect(self.connection_str) as conn, conn.cursor() as curs:
